@@ -1,4 +1,5 @@
-from prospector.formatters import json, text, grouped, emacs, yaml, pylint
+# -*- coding: utf-8 -*-
+from prospector.formatters import json, text, grouped, emacs, yaml, pylint, xunit, vscode
 
 
 __all__ = (
@@ -13,4 +14,6 @@ FORMATTERS = {
     'emacs': emacs.EmacsFormatter,
     'yaml': yaml.YamlFormatter,
     'pylint': pylint.PylintFormatter,
+    'xunit': xunit.XunitFormatter,
+    'vscode': vscode.VSCodeFormatter,
 }
