@@ -1,15 +1,23 @@
+# -*- coding: utf-8 -*-
 import os
+import sys
 
 
 class Location(object):
 
     def __init__(self, path, module, function, line, character, absolute_path=True):
+        if sys.version_info.major == 2 and isinstance(path, str):
+            # If this is not a unicode object, make it one! Some tools return
+            # paths as unicode, some as bytestring, so to ensure that they are
+            # all the same, we normalise here. For Python3 this is (probably)
+            # always a str so no need to do anything.
+            path = path.decode(sys.getfilesystemencoding())
         self.path = path
         self._path_is_absolute = absolute_path
         self.module = module or None
         self.function = function or None
         self.line = None if line == -1 else line
-        self.character = None if line == -1 else character
+        self.character = None if character == -1 else character
 
     def to_absolute_path(self, root):
         if self._path_is_absolute:
@@ -41,7 +49,7 @@ class Location(object):
     def __lt__(self, other):
         if self.path == other.path:
             if self.line == other.line:
-                return self.character < other.character
+                return (self.character or -1) < (other.character or -1)
             return (self.line or -1) < (other.line or -1)  # line can be None if it a file-global warning
         return self.path < other.path
 
@@ -81,3 +89,20 @@ class Message(object):
         if self.location == other.location:
             return self.code < other.code
         return self.location < other.location
+
+
+def make_tool_error_message(filepath, source, code, message,
+                            line=0, character=0, module=None, function=None):
+    location = Location(
+        path=filepath,
+        module=module,
+        function=function,
+        line=line,
+        character=character
+    )
+    return Message(
+        source=source,
+        code=code,
+        location=location,
+        message=message
+    )
