@@ -46,6 +46,7 @@ class ProspectorProfile(object):
         )
 
         self.output_format = profile_dict.get('output-format')
+        self.output_target = profile_dict.get('output-target')
         self.autodetect = profile_dict.get('autodetect')
         self.uses = [uses for uses in _ensure_list(profile_dict.get('uses', []))
                      if uses in ('django', 'celery', 'flask')]
@@ -92,6 +93,7 @@ class ProspectorProfile(object):
             'ignore-paths': self.ignore_paths,
             'ignore-patterns': self.ignore_patterns,
             'output-format': self.output_format,
+            'output-target': self.output_target,
             'autodetect': self.autodetect,
             'uses': self.uses,
             'max-line-length': self.max_line_length,
@@ -171,7 +173,9 @@ def _simple_merge_dict(priority, base):
 def _merge_tool_config(priority, base):
     out = dict(base.items())
     for key, value in priority.items():
-        if key in ('run', 'full', 'none'):  # pep8 has extra 'full' and 'none' options
+        # pep8 has extra 'full' and 'none' options
+        # pylint has extra 'load-plugins' option
+        if key in ('run', 'full', 'none', 'load-plugins'):
             out[key] = value
         elif key in ('options',):
             out[key] = _simple_merge_dict(value, base.get(key, {}))
