@@ -1,10 +1,18 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
 import os
 import re
-from pep8 import StyleGuide, BaseReport, register_check, DEFAULT_CONFIG, PROJECT_CONFIG
+from pycodestyle import StyleGuide, BaseReport, register_check, PROJECT_CONFIG
 from pep8ext_naming import NamingChecker
 
+try:
+    # for pep8 <= 1.5.7
+    from pycodestyle import DEFAULT_CONFIG as USER_CONFIG
+except ImportError:
+    # for pep8 >= 1.6.0
+    from pycodestyle import USER_CONFIG
+
 from prospector.message import Location, Message
 from prospector.tools.base import ToolBase
 
@@ -61,6 +69,7 @@ class ProspectorReport(BaseReport):
 class ProspectorStyleGuide(StyleGuide):
     def __init__(self, found_files, *args, **kwargs):
         self._files = found_files
+        self._module_paths = set(self._files.iter_module_paths())
 
         # Override the default reporter with our custom one.
         kwargs['reporter'] = ProspectorReport
@@ -73,11 +82,12 @@ class ProspectorStyleGuide(StyleGuide):
 
         # If the file survived pep8's exclusion rules, check it against
         # prospector's patterns.
-        if os.path.isdir(os.path.join(self._files.rootpath, filename)):
+        fullpath = os.path.join(self._files.rootpath, parent or '', filename)
+        if os.path.isdir(fullpath):
             return False
 
-        fullpath = os.path.join(self._files.rootpath, parent, filename) if parent else filename
-        return fullpath not in self._files.iter_module_paths()
+        fullpath = fullpath if parent else filename
+        return fullpath not in self._module_paths
 
 
 class Pep8Tool(ToolBase):
@@ -85,63 +95,89 @@ class Pep8Tool(ToolBase):
         super(Pep8Tool, self).__init__(*args, **kwargs)
         self.checker = None
 
-    def prepare(self, found_files, args, adaptors):
+    def configure(self, prospector_config, found_files):
         # figure out if we should use a pre-existing config file
         # such as setup.cfg or tox.ini
         external_config = None
 
         # 'none' means we ignore any external config, so just carry on
-        if args.external_config != 'none':
+        use_config = False
+
+        if prospector_config.use_external_config('pep8'):
+            use_config = True
+
             paths = [os.path.join(found_files.rootpath, name) for name in PROJECT_CONFIG]
-            paths.append(DEFAULT_CONFIG)
+            paths.append(USER_CONFIG)
+            ext_loc = prospector_config.external_config_location('pep8')
+            if ext_loc is not None:
+                paths = [ext_loc] + paths
 
             for conf_path in paths:
                 if os.path.exists(conf_path) and os.path.isfile(conf_path):
                     # this file exists - but does it have pep8 config in it?
                     header = re.compile(r'\[pep8\]')
-                    with open(conf_path) as f:
-                        if any([header.search(line) for line in f.readlines()]):
+                    with open(conf_path) as conf_file:
+                        if any([header.search(line) for line in conf_file.readlines()]):
                             external_config = conf_path
                             break
 
-        if args.external_config == 'none':
-            # if we should not use external config, we always want to
-            # use prospector's config
-            use_config = True
+        # create a list of packages, but don't include packages which are
+        # subpackages of others as checks will be duplicated
+        packages = [
+            os.path.split(p)
+            for p in found_files.iter_package_paths(abspath=False)
+        ]
+        packages.sort(key=len)
+        check_paths = set()
+        for package in packages:
+            package_path = os.path.join(*package)
+            if len(package) == 1:
+                check_paths.add(package_path)
+                continue
+            if os.path.join(*package) in check_paths:
+                continue
+            check_paths.add(package_path)
 
-        elif args.external_config == 'merge':
-            # if we should merge with any existing config, then we want
-            # to merge prospector's config
-            use_config = True
+        for filepath in found_files.iter_module_paths(abspath=False):
+            package = os.path.dirname(filepath).split(os.path.sep)
+            for i in range(0, len(package)):
+                if os.path.join(*package[:i + 1]) in check_paths:
+                    break
+            else:
+                check_paths.add(filepath)
 
-        elif args.external_config == 'only':
-            # if we should only use external config, then we don't use
-            # prospector's config *unless* there is no external config
-            use_config = external_config is None
+        check_paths = [found_files.to_absolute_path(p) for p in check_paths]
 
         # Instantiate our custom pep8 checker.
         self.checker = ProspectorStyleGuide(
-            paths=list(found_files.iter_package_paths()),
+            paths=check_paths,
             found_files=found_files,
             config_file=external_config
         )
+        if not use_config or external_config is None:
+            configured_by = None
+            # This means that we don't have existing config to use.
+            # Make sure pep8's code ignores are fully reset to zero before
+            # adding prospector-flavoured configuration.
+            # pylint: disable=attribute-defined-outside-init
+            self.checker.options.select = ()
+            self.checker.options.ignore = tuple(prospector_config.get_disabled_messages('pep8'))
 
-        if args.external_config == 'none' or external_config is None:
-            # Make sure pep8's code ignores are fully reset to zero.
-            # pylint: disable=W0201
-            self.checker.select = ()
-            self.checker.ignore = ()
-
-        # Let the adaptors & profiles do their thing.
-        for adaptor in adaptors:
-            adaptor.adapt_pep8(self.checker, use_config=use_config)
+            if 'max-line-length' in prospector_config.tool_options('pep8'):
+                self.checker.options.max_line_length = \
+                    prospector_config.tool_options('pep8')['max-line-length']
+        else:
+            configured_by = "Configuration found at %s" % external_config
 
         # if we have a command line --max-line-length argument, that
         # overrules everything
-        if args.max_line_length is not None:
-            self.checker.options.max_line_length = args.max_line_length
+        max_line_length = prospector_config.max_line_length
+        if max_line_length is not None:
+            self.checker.options.max_line_length = max_line_length
 
-    def run(self):
+        return configured_by, []
+
+    def run(self, _):
         report = self.checker.check_files()
         return report.get_messages()
 
